// 
// abs2obj.cxx : Convert FRGC 2D depth map (.abs) into a .obj mesh file.
//
// Copyright (C) 2010  Clement Creusot
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#include "vtkPolyDataMapper.h"
#include "vtkPolyData.h"
#include "vtkActor.h"
#include "vtkRenderer.h"
#include "vtkRenderWindow.h"
#include "vtkCamera.h"

#include "OBJExporter.h"
#include "ABSReader.h"
#include <ostream>

void print_help(){
  fprintf(stderr, "Usage: abs2obj filein.abs [fileout.obj [reduction_factor]]\n");
  exit(EXIT_FAILURE);
}


int main(int argc, char *argv[])
{
  std::string filein;
  std::string fileout_prefix;
  int reduction_factor = 1;

  if (argc < 2){
    print_help();
  }
  else{
    filein = argv[1];
    fileout_prefix = argv[1];
    if (argc >= 3){
      fileout_prefix = argv[2]; 
      if (argc >= 4){
	if (atoi(argv[3]) != 0){
	  reduction_factor = atoi(argv[3]);
	}
	else{
	  fprintf(stderr, "Bad Argument: the third argument is not an non null integer\n");
	  print_help();
	  
	}
      }  
    }  
    
  }

  ABSReader* dataIn = ABSReader::New();
  dataIn->SetFileName(filein.c_str());
  dataIn->SetreductionFactor(reduction_factor);

  vtkPolyDataMapper *modelMapper = vtkPolyDataMapper::New();
  modelMapper->SetInput(dataIn->GetOutput());

  vtkActor *modelActor = vtkActor::New();
  modelActor->SetMapper(modelMapper);

  vtkRenderer *ren1 = vtkRenderer::New();
  ren1->AddActor(modelActor);

  vtkRenderWindow *renWin = vtkRenderWindow::New();
  renWin->AddRenderer(ren1);
  renWin->SetSize(600, 600);

  OBJExporter *exp = OBJExporter::New();
  exp->SetRenderWindow(renWin);
  exp->SetFilePrefix(fileout_prefix.c_str());
  exp->Write();
  

  dataIn->Delete();
  modelMapper->Delete();
  modelActor->Delete();
  ren1->Delete();
  renWin->Delete();

  return 0;
}




